import os
from typing import Optional

import requests
from dotenv import load_dotenv
from pydantic import BaseModel

load_dotenv()


class KVConfig(BaseModel):
    url: str
    rest_api_url: str
    rest_api_token: str
    rest_api_read_only_token: str


class Opts(BaseModel):
    ex: Optional[int]
    px: Optional[int]
    exat: None
    pxat: None
    keepTtl: None


class KV:
    """
    wapper for https://vercel.com/docs/storage/vercel-kv/rest-api
    """

    def __init__(self, kv_config: Optional[KVConfig] = None):
        if kv_config is None:
            self.kv_config = KVConfig(
                url=os.getenv("VERCEL_KV_URL"),
                rest_api_url=os.getenv("VERCEL_KV_REST_API_URL"),
                rest_api_token=os.getenv("VERCEL_KV_REST_API_TOKEN"),
                rest_api_read_only_token=os.getenv(
                    "VERCEL_KV_REST_API_READ_ONLY_TOKEN"
                ),
            )
        else:
            self.kv_config = kv_config

    def get_kv_conf(self) -> KVConfig:
        return self.kv_config

    def has_auth(self) -> bool:
        kv_config = KV.get_kv_conf()
        headers = {
            'Authorization': f'Bearer {self.kv_config.rest_api_token}',
        }
        resp = requests.get(self.kv_config.rest_api_url, headers=headers)
        return resp.json()['error'] != 'Unauthorized'

    def set(self, key, value, opts: Optional[Opts] = None) -> bool:
        headers = {
            'Authorization': f'Bearer {self.kv_config.rest_api_token}',
        }

        url = f'{self.kv_config.rest_api_url}/set/{key}/{value}'

        if opts is not None and opts.ex is not None:
            url = f'{url}/ex/{opts.ex}'

        resp = requests.get(url, headers=headers)
        return resp.json()['result']

    def get(self, key) -> bool:
        headers = {
            'Authorization': f'Bearer {self.kv_config.rest_api_token}',
        }

        resp = requests.get(f'{self.kv_config.rest_api_url}/get/{key}', headers=headers)
        return resp.json()['result']



import pathlib

from setuptools import setup

# The directory containing this file
HERE = pathlib.Path(__file__).parent

# The text of the README file
README = (HERE / "README.md").read_text()

# This call to setup() does all the work
setup(
    name="vercel_kv",
    version="0.1.5",
    description="https://vercel.com/docs/storage/vercel-kv/rest-api",
    long_description=README,
    long_description_content_type="text/markdown",
    url="https://github.com/bestK/python-vercel-kv",
    author="bestk",
    license="MIT",
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
    ],
    package_dir={"": "src"},
    include_package_data=True,
    install_requires=["python-dotenv==1.0.0", "requests~=2.31.0", "pydantic~=2.1.1"],
    extras_require={'dev': ['pytest', 'tox']},
    entry_points={},
)
